@@ -12,10 +12,11 @@ import os
 from click.testing import CliRunner
 
 import boto3
+from moto import mock_ssm  # pylint: disable=E0401
+
 from k8t import __license__, __version__
 from k8t.cli import root
 from k8t.scaffolding import list_available_templates
-from moto import mock_ssm
 
 
 def test_print_version():
@@ -25,6 +26,7 @@ def test_print_version():
     assert result.exit_code == 0
     assert __version__ in result.output
 
+
 def test_print_license():
     runner = CliRunner()
 
@@ -32,6 +34,7 @@ def test_print_license():
     assert result.exit_code == 0
     assert __license__ in result.output
 
+
 def test_new_project():
     runner = CliRunner()
 
@@ -46,6 +49,7 @@ def test_new_project():
         assert os.path.exists('test/values.yaml')
         assert os.path.exists('test/config.yaml')
 
+
 def test_new_cluster():
     runner = CliRunner()
 
@@ -60,6 +64,7 @@ def test_new_cluster():
         assert os.path.exists('./clusters/cluster-1/values.yaml')
         assert os.path.exists('./clusters/cluster-1/config.yaml')
 
+
 def test_new_environment():
     runner = CliRunner()
 
@@ -84,6 +89,7 @@ def test_new_environment():
         assert os.path.exists('./clusters/cluster-1/environments/production/values.yaml')
         assert os.path.exists('./clusters/cluster-1/environments/production/config.yaml')
 
+
 def test_new_template():
     template_type = list(list_available_templates())[0]
     runner = CliRunner()
@@ -137,15 +143,16 @@ def test_new_template():
             assert f'Template created: ./templates/{template_type}.yaml.j2' in result.output
             assert os.path.exists(f'./templates/{template_type}.yaml.j2')
 
+
 def test_get_clusters():
     runner = CliRunner()
 
     result = runner.invoke(root, ['get', 'clusters', 'tests/resources/good'])
     assert result.exit_code == 0
-    # TODO: Fix that, should return clusters, not environments
     assert 'cluster-1' in result.output
     assert 'cluster-2' in result.output
 
+
 def test_get_environments():
     runner = CliRunner()
 
@@ -165,7 +172,8 @@ def test_get_environments():
     assert result.exit_code == 0
     assert not result.output
 
-def test_get_templates():
+
+def test_get_templates():  # pylint: disable=R0915
     runner = CliRunner()
 
     result = runner.invoke(root, ['get', 'templates', 'tests/resources/good'])
@@ -224,7 +232,8 @@ def test_get_templates():
     assert 'cluster-1-env-template.yaml.j2' not in result.output
     assert 'composite-template.yaml.j2' in result.output
 
-def test_validate_successful():
+
+def test_validate_successful():  # pylint: disable=R0915
     runner = CliRunner()
 
     result = runner.invoke(root, ['validate', 'tests/resources/good'])
@@ -283,11 +292,12 @@ def test_validate_successful():
     assert 'cluster-1-env-template.yaml.j2: ✔' not in result.output
     assert 'composite-template.yaml.j2: ✔' in result.output
 
+
 def test_validate_with_values():
     runner = CliRunner()
 
     result = runner.invoke(root, ['validate', 'tests/resources/missing_values'])
-    assert result.exit_code # TODO: Should be 1
+    assert result.exit_code == 1
     assert 'template.yaml.j2: ✗' in result.output
     assert '- undefined variable: test' in result.output
 
@@ -302,6 +312,7 @@ def test_validate_with_values():
     assert result.exit_code == 0
     assert 'template.yaml.j2: ✔' in result.output
 
+
 def test_validate_failure():
     runner = CliRunner()
 
@@ -310,7 +321,7 @@ def test_validate_failure():
     # assert 'filter-template.yaml.j2: ✗' in result.output
     # assert 'nested-value-adding-template.yaml.j2: ✗' in result.output
     # assert 'nested-value-template.yaml.j2: ✗' in result.output
-    assert 'secret-template.yaml.j2: ✗' in result.output # TODO: Crushes, check file
+    assert 'secret-template.yaml.j2: ✗' in result.output
     assert 'several-template.yaml.j2: ✗' in result.output
     assert 'value-template.yaml.j2: ✗' in result.output
     assert 'composite-template.yaml.j2: ✗' in result.output
@@ -335,6 +346,13 @@ def test_gen():
         assert result.exit_code == 0
         assert result.output == file.read()
 
+    with open('tests/resources/results/default-with-cli-values.yaml', 'r') as file:
+        result = runner.invoke(
+            root, ['gen', '--value', 'foo', '77950e8', 'tests/resources/good']
+        )
+        assert result.exit_code == 0
+        assert result.output == file.read()
+
     with open('tests/resources/results/some-env.yaml', 'r') as file:
         result = runner.invoke(root, ['gen', '-e', 'some-env', 'tests/resources/good'])
         assert result.exit_code == 0
